StructuredRemoteCompactionServer

Struct StructuredRemoteCompactionServer 

pub struct StructuredRemoteCompactionServer { /* private fields */ }
A remote compaction server pre-configured to resolve structured data type merge operators (e.g. list) from request metadata.

This wraps RemoteCompactionServer and automatically registers the structured merge operator resolver on construction.

Implementations

Source

impl StructuredRemoteCompactionServer

pub fn new(config: Config) -> Result<Self>

pub fn supported_merge_operator_ids(&self) -> Vec<String>

pub fn serve(&self, address: &str) -> Result<()>

pub fn handle_connection(&self, stream: TcpStream) -> Result<()>

pub fn inner(&self) -> &RemoteCompactionServer

pub fn close(&self)