pub struct StructuredWriteBatch { /* private fields */ }Expand description
Structured write batch wrapper.
Each operation is encoded and written into the inner cobble::WriteBatch immediately, so we
avoid a second typed-op staging buffer and an extra conversion pass at flush time.
Implementations
Sourceimpl StructuredWriteBatch
impl StructuredWriteBatch
pub fn put<K, V>( &mut self, bucket: u16, key: K, column: u16, value: V, ) -> Result<()>
pub fn put_with_options<K, V>( &mut self, bucket: u16, key: K, column: u16, value: V, options: &WriteOptions, ) -> Result<()>
pub fn delete<K>(&mut self, bucket: u16, key: K, column: u16)
pub fn merge<K, V>( &mut self, bucket: u16, key: K, column: u16, value: V, ) -> Result<()>
pub fn merge_with_options<K, V>( &mut self, bucket: u16, key: K, column: u16, value: V, options: &WriteOptions, ) -> Result<()>